@@ -21,6 +21,7 @@ __revision__ = '$Id$'
 # You may use and distribute this software under the terms of the
 # GNU General Public License, version 2 or later
 
+import locale
 import logging
 import os
 import string
@@ -485,6 +486,14 @@ def urlretrieve2(url, filename=None, reporthook=None, data=None):
     tfp.close()
     return [filename, response.info()]
 
+def get_locale():
+  os_locale = locale.getdefaultlocale()[0]
+
+  if os_locale is None:
+    return "en-US"
+
+  return os_locale.replace('_', '-')
+
 
 class UAFancyURLopener(FancyURLopener):
     # use Firefox 3.0 User-Agent string from Windows XP
@@ -496,6 +505,7 @@ class UAFancyURLopener(FancyURLopener):
         # is used by UMTS connections. compression breaks the movie import plugins sometimes
         self.addheaders.append(('Cache-Control', 'no-cache'))
         self.addheaders.append(('Pragma', 'no-cache'))
+        self.addheaders.append(('Accept-Language', '%s,en;q=0.5' % get_locale()))
 
     def open(self, fullurl, data=None):
         # prevent blocking calls which doesn't come back
